/* Enum.c generated by valac 0.56.19, the Vala compiler
 * generated from Enum.vala, do not modify */

/*
 * Copyright © 2023 Alain M. (https://github.com/alainm23/planify)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA
 *
 * Authored by: Alain M. <alainmh23@gmail.com>
 */

#include "planify.h"
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <glib/gi18n-lib.h>
#include <gio/gio.h>
#include <glib-object.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
enum  {
	SYNC_STATUS_0_PROPERTY,
	SYNC_STATUS_ERROR_TYPE_PROPERTY,
	SYNC_STATUS_TITLE_PROPERTY,
	SYNC_STATUS_DESCRIPTION_PROPERTY,
	SYNC_STATUS_TOOLTIP_PROPERTY,
	SYNC_STATUS_NUM_PROPERTIES
};
static GParamSpec* sync_status_properties[SYNC_STATUS_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))

struct _SyncStatusPrivate {
	SyncErrorType _error_type;
	gchar* _title;
	gchar* _description;
};

static gint SyncStatus_private_offset;
static gpointer sync_status_parent_class = NULL;

static gboolean _int_equal (const gint * s1,
                     const gint * s2);
static void sync_status_finalize (GObject * obj);
static GType sync_status_get_type_once (void);
static void _vala_sync_status_get_property (GObject * object,
                                     guint property_id,
                                     GValue * value,
                                     GParamSpec * pspec);
static void _vala_sync_status_set_property (GObject * object,
                                     guint property_id,
                                     const GValue * value,
                                     GParamSpec * pspec);

static GType
color_scheme_get_type_once (void)
{
	static const GEnumValue values[] = {{COLOR_SCHEME_NO_PREFERENCE, "COLOR_SCHEME_NO_PREFERENCE", "no-preference"}, {COLOR_SCHEME_DARK, "COLOR_SCHEME_DARK", "dark"}, {COLOR_SCHEME_LIGHT, "COLOR_SCHEME_LIGHT", "light"}, {0, NULL, NULL}};
	GType color_scheme_type_id;
	color_scheme_type_id = g_enum_register_static ("ColorScheme", values);
	return color_scheme_type_id;
}

GType
color_scheme_get_type (void)
{
	static volatile gsize color_scheme_type_id__once = 0;
	if (g_once_init_enter (&color_scheme_type_id__once)) {
		GType color_scheme_type_id;
		color_scheme_type_id = color_scheme_get_type_once ();
		g_once_init_leave (&color_scheme_type_id__once, color_scheme_type_id);
	}
	return color_scheme_type_id__once;
}

static GType
notification_style_get_type_once (void)
{
	static const GEnumValue values[] = {{NOTIFICATION_STYLE_NORMAL, "NOTIFICATION_STYLE_NORMAL", "normal"}, {NOTIFICATION_STYLE_ERROR, "NOTIFICATION_STYLE_ERROR", "error"}, {0, NULL, NULL}};
	GType notification_style_type_id;
	notification_style_type_id = g_enum_register_static ("NotificationStyle", values);
	return notification_style_type_id;
}

GType
notification_style_get_type (void)
{
	static volatile gsize notification_style_type_id__once = 0;
	if (g_once_init_enter (&notification_style_type_id__once)) {
		GType notification_style_type_id;
		notification_style_type_id = notification_style_get_type_once ();
		g_once_init_leave (&notification_style_type_id__once, notification_style_type_id);
	}
	return notification_style_type_id__once;
}

gchar*
project_view_style_to_string (ProjectViewStyle self)
{
	gchar* result;
	switch (self) {
		case PROJECT_VIEW_STYLE_LIST:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup ("list");
			result = _tmp0_;
			return result;
		}
		case PROJECT_VIEW_STYLE_BOARD:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup ("board");
			result = _tmp1_;
			return result;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
}

ProjectViewStyle
project_view_style_parse (const gchar* value)
{
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	static GQuark _tmp1_label1 = 0;
	ProjectViewStyle result;
	g_return_val_if_fail (value != NULL, 0);
	_tmp0_ = value;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("list")))) {
		switch (0) {
			default:
			{
				result = PROJECT_VIEW_STYLE_LIST;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label1) ? _tmp1_label1 : (_tmp1_label1 = g_quark_from_static_string ("board")))) {
		switch (0) {
			default:
			{
				result = PROJECT_VIEW_STYLE_BOARD;
				return result;
			}
		}
	} else {
		switch (0) {
			default:
			{
				g_assert_not_reached ();
			}
		}
	}
}

static GType
project_view_style_get_type_once (void)
{
	static const GEnumValue values[] = {{PROJECT_VIEW_STYLE_LIST, "PROJECT_VIEW_STYLE_LIST", "list"}, {PROJECT_VIEW_STYLE_BOARD, "PROJECT_VIEW_STYLE_BOARD", "board"}, {0, NULL, NULL}};
	GType project_view_style_type_id;
	project_view_style_type_id = g_enum_register_static ("ProjectViewStyle", values);
	return project_view_style_type_id;
}

GType
project_view_style_get_type (void)
{
	static volatile gsize project_view_style_type_id__once = 0;
	if (g_once_init_enter (&project_view_style_type_id__once)) {
		GType project_view_style_type_id;
		project_view_style_type_id = project_view_style_get_type_once ();
		g_once_init_leave (&project_view_style_type_id__once, project_view_style_type_id);
	}
	return project_view_style_type_id__once;
}

gchar*
project_icon_style_to_string (ProjectIconStyle self)
{
	gchar* result;
	switch (self) {
		case PROJECT_ICON_STYLE_PROGRESS:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup ("progress");
			result = _tmp0_;
			return result;
		}
		case PROJECT_ICON_STYLE_EMOJI:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup ("emoji");
			result = _tmp1_;
			return result;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
}

ProjectIconStyle
project_icon_style_parse (const gchar* value)
{
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	static GQuark _tmp1_label1 = 0;
	ProjectIconStyle result;
	g_return_val_if_fail (value != NULL, 0);
	_tmp0_ = value;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("progress")))) {
		switch (0) {
			default:
			{
				result = PROJECT_ICON_STYLE_PROGRESS;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label1) ? _tmp1_label1 : (_tmp1_label1 = g_quark_from_static_string ("emoji")))) {
		switch (0) {
			default:
			{
				result = PROJECT_ICON_STYLE_EMOJI;
				return result;
			}
		}
	} else {
		switch (0) {
			default:
			{
				g_assert_not_reached ();
			}
		}
	}
}

static GType
project_icon_style_get_type_once (void)
{
	static const GEnumValue values[] = {{PROJECT_ICON_STYLE_PROGRESS, "PROJECT_ICON_STYLE_PROGRESS", "progress"}, {PROJECT_ICON_STYLE_EMOJI, "PROJECT_ICON_STYLE_EMOJI", "emoji"}, {0, NULL, NULL}};
	GType project_icon_style_type_id;
	project_icon_style_type_id = g_enum_register_static ("ProjectIconStyle", values);
	return project_icon_style_type_id;
}

GType
project_icon_style_get_type (void)
{
	static volatile gsize project_icon_style_type_id__once = 0;
	if (g_once_init_enter (&project_icon_style_type_id__once)) {
		GType project_icon_style_type_id;
		project_icon_style_type_id = project_icon_style_get_type_once ();
		g_once_init_leave (&project_icon_style_type_id__once, project_icon_style_type_id);
	}
	return project_icon_style_type_id__once;
}

gchar*
source_type_to_string (SourceType self)
{
	gchar* result;
	switch (self) {
		case SOURCE_TYPE_NONE:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup ("none");
			result = _tmp0_;
			return result;
		}
		case SOURCE_TYPE_LOCAL:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup ("local");
			result = _tmp1_;
			return result;
		}
		case SOURCE_TYPE_TODOIST:
		{
			gchar* _tmp2_;
			_tmp2_ = g_strdup ("todoist");
			result = _tmp2_;
			return result;
		}
		case SOURCE_TYPE_GOOGLE_TASKS:
		{
			gchar* _tmp3_;
			_tmp3_ = g_strdup ("google-tasks");
			result = _tmp3_;
			return result;
		}
		case SOURCE_TYPE_CALDAV:
		{
			gchar* _tmp4_;
			_tmp4_ = g_strdup ("caldav");
			result = _tmp4_;
			return result;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
}

SourceType
source_type_parse (const gchar* value)
{
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	static GQuark _tmp1_label1 = 0;
	static GQuark _tmp1_label2 = 0;
	static GQuark _tmp1_label3 = 0;
	SourceType result;
	g_return_val_if_fail (value != NULL, 0);
	_tmp0_ = value;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("local")))) {
		switch (0) {
			default:
			{
				result = SOURCE_TYPE_LOCAL;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label1) ? _tmp1_label1 : (_tmp1_label1 = g_quark_from_static_string ("todoist")))) {
		switch (0) {
			default:
			{
				result = SOURCE_TYPE_TODOIST;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label2) ? _tmp1_label2 : (_tmp1_label2 = g_quark_from_static_string ("google-tasks")))) {
		switch (0) {
			default:
			{
				result = SOURCE_TYPE_GOOGLE_TASKS;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label3) ? _tmp1_label3 : (_tmp1_label3 = g_quark_from_static_string ("caldav")))) {
		switch (0) {
			default:
			{
				result = SOURCE_TYPE_CALDAV;
				return result;
			}
		}
	} else {
		switch (0) {
			default:
			{
				result = SOURCE_TYPE_NONE;
				return result;
			}
		}
	}
}

static GType
source_type_get_type_once (void)
{
	static const GEnumValue values[] = {{SOURCE_TYPE_NONE, "SOURCE_TYPE_NONE", "none"}, {SOURCE_TYPE_LOCAL, "SOURCE_TYPE_LOCAL", "local"}, {SOURCE_TYPE_TODOIST, "SOURCE_TYPE_TODOIST", "todoist"}, {SOURCE_TYPE_GOOGLE_TASKS, "SOURCE_TYPE_GOOGLE_TASKS", "google-tasks"}, {SOURCE_TYPE_CALDAV, "SOURCE_TYPE_CALDAV", "caldav"}, {0, NULL, NULL}};
	GType source_type_type_id;
	source_type_type_id = g_enum_register_static ("SourceType", values);
	return source_type_type_id;
}

GType
source_type_get_type (void)
{
	static volatile gsize source_type_type_id__once = 0;
	if (g_once_init_enter (&source_type_type_id__once)) {
		GType source_type_type_id;
		source_type_type_id = source_type_get_type_once ();
		g_once_init_leave (&source_type_type_id__once, source_type_type_id);
	}
	return source_type_type_id__once;
}

static GType
pane_type_get_type_once (void)
{
	static const GEnumValue values[] = {{PANE_TYPE_FILTER, "PANE_TYPE_FILTER", "filter"}, {PANE_TYPE_FAVORITE, "PANE_TYPE_FAVORITE", "favorite"}, {PANE_TYPE_PROJECT, "PANE_TYPE_PROJECT", "project"}, {PANE_TYPE_LABEL, "PANE_TYPE_LABEL", "label"}, {0, NULL, NULL}};
	GType pane_type_type_id;
	pane_type_type_id = g_enum_register_static ("PaneType", values);
	return pane_type_type_id;
}

GType
pane_type_get_type (void)
{
	static volatile gsize pane_type_type_id__once = 0;
	if (g_once_init_enter (&pane_type_type_id__once)) {
		GType pane_type_type_id;
		pane_type_type_id = pane_type_get_type_once ();
		g_once_init_leave (&pane_type_type_id__once, pane_type_type_id);
	}
	return pane_type_type_id__once;
}

static GType
loading_button_type_get_type_once (void)
{
	static const GEnumValue values[] = {{LOADING_BUTTON_TYPE_LABEL, "LOADING_BUTTON_TYPE_LABEL", "label"}, {LOADING_BUTTON_TYPE_ICON, "LOADING_BUTTON_TYPE_ICON", "icon"}, {0, NULL, NULL}};
	GType loading_button_type_type_id;
	loading_button_type_type_id = g_enum_register_static ("LoadingButtonType", values);
	return loading_button_type_type_id;
}

GType
loading_button_type_get_type (void)
{
	static volatile gsize loading_button_type_type_id__once = 0;
	if (g_once_init_enter (&loading_button_type_type_id__once)) {
		GType loading_button_type_type_id;
		loading_button_type_type_id = loading_button_type_get_type_once ();
		g_once_init_leave (&loading_button_type_type_id__once, loading_button_type_type_id);
	}
	return loading_button_type_type_id__once;
}

gchar*
object_type_get_header (ObjectType self)
{
	gchar* result;
	switch (self) {
		case OBJECT_TYPE_PROJECT:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup (_ ("Projects"));
			result = _tmp0_;
			return result;
		}
		case OBJECT_TYPE_SECTION:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup (_ ("Sections"));
			result = _tmp1_;
			return result;
		}
		case OBJECT_TYPE_ITEM:
		{
			gchar* _tmp2_;
			_tmp2_ = g_strdup (_ ("Tasks"));
			result = _tmp2_;
			return result;
		}
		case OBJECT_TYPE_LABEL:
		{
			gchar* _tmp3_;
			_tmp3_ = g_strdup (_ ("Labels"));
			result = _tmp3_;
			return result;
		}
		case OBJECT_TYPE_FILTER:
		{
			gchar* _tmp4_;
			_tmp4_ = g_strdup (_ ("Filters"));
			result = _tmp4_;
			return result;
		}
		case OBJECT_TYPE_TASK:
		{
			gchar* _tmp5_;
			_tmp5_ = g_strdup (_ ("Tasks"));
			result = _tmp5_;
			return result;
		}
		case OBJECT_TYPE_TASK_LIST:
		{
			gchar* _tmp6_;
			_tmp6_ = g_strdup (_ ("Lists"));
			result = _tmp6_;
			return result;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
}

static GType
object_type_get_type_once (void)
{
	static const GEnumValue values[] = {{OBJECT_TYPE_PROJECT, "OBJECT_TYPE_PROJECT", "project"}, {OBJECT_TYPE_SECTION, "OBJECT_TYPE_SECTION", "section"}, {OBJECT_TYPE_ITEM, "OBJECT_TYPE_ITEM", "item"}, {OBJECT_TYPE_LABEL, "OBJECT_TYPE_LABEL", "label"}, {OBJECT_TYPE_TASK, "OBJECT_TYPE_TASK", "task"}, {OBJECT_TYPE_TASK_LIST, "OBJECT_TYPE_TASK_LIST", "task-list"}, {OBJECT_TYPE_FILTER, "OBJECT_TYPE_FILTER", "filter"}, {0, NULL, NULL}};
	GType object_type_type_id;
	object_type_type_id = g_enum_register_static ("ObjectType", values);
	return object_type_type_id;
}

GType
object_type_get_type (void)
{
	static volatile gsize object_type_type_id__once = 0;
	if (g_once_init_enter (&object_type_type_id__once)) {
		GType object_type_type_id;
		object_type_type_id = object_type_get_type_once ();
		g_once_init_leave (&object_type_type_id__once, object_type_type_id);
	}
	return object_type_type_id__once;
}

static GType
recurrency_end_type_get_type_once (void)
{
	static const GEnumValue values[] = {{RECURRENCY_END_TYPE_NEVER, "RECURRENCY_END_TYPE_NEVER", "never"}, {RECURRENCY_END_TYPE_ON_DATE, "RECURRENCY_END_TYPE_ON_DATE", "on-date"}, {RECURRENCY_END_TYPE_AFTER, "RECURRENCY_END_TYPE_AFTER", "after"}, {0, NULL, NULL}};
	GType recurrency_end_type_type_id;
	recurrency_end_type_type_id = g_enum_register_static ("RecurrencyEndType", values);
	return recurrency_end_type_type_id;
}

GType
recurrency_end_type_get_type (void)
{
	static volatile gsize recurrency_end_type_type_id__once = 0;
	if (g_once_init_enter (&recurrency_end_type_type_id__once)) {
		GType recurrency_end_type_type_id;
		recurrency_end_type_type_id = recurrency_end_type_get_type_once ();
		g_once_init_leave (&recurrency_end_type_type_id__once, recurrency_end_type_type_id);
	}
	return recurrency_end_type_type_id__once;
}

static gboolean
_int_equal (const gint * s1,
            const gint * s2)
{
	if (s1 == s2) {
		return TRUE;
	}
	if (s1 == NULL) {
		return FALSE;
	}
	if (s2 == NULL) {
		return FALSE;
	}
	return (*s1) == (*s2);
}

gchar*
recurrency_type_to_friendly_string (RecurrencyType self,
                                    gint* interval)
{
	gint _tmp0_ = 0;
	gboolean _tmp1_ = FALSE;
	gint count = 0;
	gchar* result;
	if (interval == NULL) {
		_tmp1_ = TRUE;
	} else {
		gint _tmp2_;
		_tmp2_ = 0;
		_tmp1_ = _int_equal (interval, &_tmp2_) == TRUE;
	}
	if (_tmp1_) {
		_tmp0_ = 1;
	} else {
		_tmp0_ = *interval;
	}
	count = _tmp0_;
	switch (self) {
		case RECURRENCY_TYPE_NONE:
		{
			gchar* _tmp3_;
			_tmp3_ = g_strdup (_ ("Don't Repeat"));
			result = _tmp3_;
			return result;
		}
		case RECURRENCY_TYPE_MINUTELY:
		{
			gchar* _tmp4_;
			_tmp4_ = g_strdup_printf (ngettext ("Every minute", "Every %d minutes", (gulong) count), count);
			result = _tmp4_;
			return result;
		}
		case RECURRENCY_TYPE_HOURLY:
		{
			gchar* _tmp5_;
			_tmp5_ = g_strdup_printf (ngettext ("Every hour", "Every %d hours", (gulong) count), count);
			result = _tmp5_;
			return result;
		}
		case RECURRENCY_TYPE_EVERY_DAY:
		{
			gchar* _tmp6_;
			_tmp6_ = g_strdup_printf (ngettext ("Every day", "Every %d days", (gulong) count), count);
			result = _tmp6_;
			return result;
		}
		case RECURRENCY_TYPE_EVERY_WEEK:
		{
			gchar* _tmp7_;
			_tmp7_ = g_strdup_printf (ngettext ("Every week", "Every %d weeks", (gulong) count), count);
			result = _tmp7_;
			return result;
		}
		case RECURRENCY_TYPE_EVERY_MONTH:
		{
			gchar* _tmp8_;
			_tmp8_ = g_strdup_printf (ngettext ("Every month", "Every %d months", (gulong) count), count);
			result = _tmp8_;
			return result;
		}
		case RECURRENCY_TYPE_EVERY_YEAR:
		{
			gchar* _tmp9_;
			_tmp9_ = g_strdup_printf (ngettext ("Every year", "Every %d years", (gulong) count), count);
			result = _tmp9_;
			return result;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
}

static GType
recurrency_type_get_type_once (void)
{
	static const GEnumValue values[] = {{RECURRENCY_TYPE_MINUTELY, "RECURRENCY_TYPE_MINUTELY", "minutely"}, {RECURRENCY_TYPE_HOURLY, "RECURRENCY_TYPE_HOURLY", "hourly"}, {RECURRENCY_TYPE_EVERY_DAY, "RECURRENCY_TYPE_EVERY_DAY", "every-day"}, {RECURRENCY_TYPE_EVERY_WEEK, "RECURRENCY_TYPE_EVERY_WEEK", "every-week"}, {RECURRENCY_TYPE_EVERY_MONTH, "RECURRENCY_TYPE_EVERY_MONTH", "every-month"}, {RECURRENCY_TYPE_EVERY_YEAR, "RECURRENCY_TYPE_EVERY_YEAR", "every-year"}, {RECURRENCY_TYPE_NONE, "RECURRENCY_TYPE_NONE", "none"}, {0, NULL, NULL}};
	GType recurrency_type_type_id;
	recurrency_type_type_id = g_enum_register_static ("RecurrencyType", values);
	return recurrency_type_type_id;
}

GType
recurrency_type_get_type (void)
{
	static volatile gsize recurrency_type_type_id__once = 0;
	if (g_once_init_enter (&recurrency_type_type_id__once)) {
		GType recurrency_type_type_id;
		recurrency_type_type_id = recurrency_type_get_type_once ();
		g_once_init_leave (&recurrency_type_type_id__once, recurrency_type_type_id);
	}
	return recurrency_type_type_id__once;
}

gchar*
picker_type_to_string (PickerType self)
{
	gchar* result;
	switch (self) {
		case PICKER_TYPE_PROJECTS:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup ("projects");
			result = _tmp0_;
			return result;
		}
		case PICKER_TYPE_SECTIONS:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup ("sections");
			result = _tmp1_;
			return result;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
}

static GType
picker_type_get_type_once (void)
{
	static const GEnumValue values[] = {{PICKER_TYPE_PROJECTS, "PICKER_TYPE_PROJECTS", "projects"}, {PICKER_TYPE_SECTIONS, "PICKER_TYPE_SECTIONS", "sections"}, {0, NULL, NULL}};
	GType picker_type_type_id;
	picker_type_type_id = g_enum_register_static ("PickerType", values);
	return picker_type_type_id;
}

GType
picker_type_get_type (void)
{
	static volatile gsize picker_type_type_id__once = 0;
	if (g_once_init_enter (&picker_type_type_id__once)) {
		GType picker_type_type_id;
		picker_type_type_id = picker_type_get_type_once ();
		g_once_init_leave (&picker_type_type_id__once, picker_type_type_id);
	}
	return picker_type_type_id__once;
}

static GType
new_task_position_get_type_once (void)
{
	static const GEnumValue values[] = {{NEW_TASK_POSITION_START, "NEW_TASK_POSITION_START", "start"}, {NEW_TASK_POSITION_END, "NEW_TASK_POSITION_END", "end"}, {0, NULL, NULL}};
	GType new_task_position_type_id;
	new_task_position_type_id = g_enum_register_static ("NewTaskPosition", values);
	return new_task_position_type_id;
}

GType
new_task_position_get_type (void)
{
	static volatile gsize new_task_position_type_id__once = 0;
	if (g_once_init_enter (&new_task_position_type_id__once)) {
		GType new_task_position_type_id;
		new_task_position_type_id = new_task_position_get_type_once ();
		g_once_init_leave (&new_task_position_type_id__once, new_task_position_type_id);
	}
	return new_task_position_type_id__once;
}

gchar*
cal_dav_type_to_string (CalDAVType self)
{
	gchar* result;
	switch (self) {
		case CAL_DAV_TYPE_NEXTCLOUD:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup ("nextcloud");
			result = _tmp0_;
			return result;
		}
		case CAL_DAV_TYPE_GENERIC:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup ("generic");
			result = _tmp1_;
			return result;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
}

gchar*
cal_dav_type_title (CalDAVType self)
{
	gchar* result;
	switch (self) {
		case CAL_DAV_TYPE_NEXTCLOUD:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup (_ ("Nextcloud"));
			result = _tmp0_;
			return result;
		}
		case CAL_DAV_TYPE_GENERIC:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup (_ ("CalDAV"));
			result = _tmp1_;
			return result;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
}

CalDAVType
cal_dav_type_parse_index (guint value)
{
	CalDAVType result;
	switch (value) {
		case 0:
		{
			result = CAL_DAV_TYPE_NEXTCLOUD;
			return result;
		}
		case 1:
		{
			result = CAL_DAV_TYPE_GENERIC;
			return result;
		}
		default:
		{
			result = CAL_DAV_TYPE_NEXTCLOUD;
			return result;
		}
	}
}

CalDAVType
cal_dav_type_parse (const gchar* value)
{
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	static GQuark _tmp1_label1 = 0;
	CalDAVType result;
	g_return_val_if_fail (value != NULL, 0);
	_tmp0_ = value;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("nextcloud")))) {
		switch (0) {
			default:
			{
				result = CAL_DAV_TYPE_NEXTCLOUD;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label1) ? _tmp1_label1 : (_tmp1_label1 = g_quark_from_static_string ("generic")))) {
		switch (0) {
			default:
			{
				result = CAL_DAV_TYPE_GENERIC;
				return result;
			}
		}
	} else {
		switch (0) {
			default:
			{
				result = CAL_DAV_TYPE_NEXTCLOUD;
				return result;
			}
		}
	}
}

static GType
cal_dav_type_get_type_once (void)
{
	static const GEnumValue values[] = {{CAL_DAV_TYPE_NEXTCLOUD, "CAL_DAV_TYPE_NEXTCLOUD", "nextcloud"}, {CAL_DAV_TYPE_GENERIC, "CAL_DAV_TYPE_GENERIC", "generic"}, {0, NULL, NULL}};
	GType cal_dav_type_type_id;
	cal_dav_type_type_id = g_enum_register_static ("CalDAVType", values);
	return cal_dav_type_type_id;
}

GType
cal_dav_type_get_type (void)
{
	static volatile gsize cal_dav_type_type_id__once = 0;
	if (g_once_init_enter (&cal_dav_type_type_id__once)) {
		GType cal_dav_type_type_id;
		cal_dav_type_type_id = cal_dav_type_get_type_once ();
		g_once_init_leave (&cal_dav_type_type_id__once, cal_dav_type_type_id);
	}
	return cal_dav_type_type_id__once;
}

gchar*
filter_item_type_to_string (FilterItemType self)
{
	gchar* result;
	switch (self) {
		case FILTER_ITEM_TYPE_PRIORITY:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup ("priority");
			result = _tmp0_;
			return result;
		}
		case FILTER_ITEM_TYPE_LABEL:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup ("label");
			result = _tmp1_;
			return result;
		}
		case FILTER_ITEM_TYPE_DUE_DATE:
		{
			gchar* _tmp2_;
			_tmp2_ = g_strdup ("due-date");
			result = _tmp2_;
			return result;
		}
		case FILTER_ITEM_TYPE_SECTION:
		{
			gchar* _tmp3_;
			_tmp3_ = g_strdup ("section");
			result = _tmp3_;
			return result;
		}
		case FILTER_ITEM_TYPE_ASSIGNMENT:
		{
			gchar* _tmp4_;
			_tmp4_ = g_strdup ("assignment");
			result = _tmp4_;
			return result;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
}

gchar*
filter_item_type_get_title (FilterItemType self)
{
	gchar* result;
	switch (self) {
		case FILTER_ITEM_TYPE_PRIORITY:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup (_ ("Priority"));
			result = _tmp0_;
			return result;
		}
		case FILTER_ITEM_TYPE_LABEL:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup (_ ("Label"));
			result = _tmp1_;
			return result;
		}
		case FILTER_ITEM_TYPE_DUE_DATE:
		{
			gchar* _tmp2_;
			_tmp2_ = g_strdup (_ ("Due Date"));
			result = _tmp2_;
			return result;
		}
		case FILTER_ITEM_TYPE_SECTION:
		{
			gchar* _tmp3_;
			_tmp3_ = g_strdup (_ ("Section"));
			result = _tmp3_;
			return result;
		}
		case FILTER_ITEM_TYPE_ASSIGNMENT:
		{
			gchar* _tmp4_;
			_tmp4_ = g_strdup (_ ("Assignment"));
			result = _tmp4_;
			return result;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
}

gchar*
filter_item_type_get_icon (FilterItemType self)
{
	gchar* result;
	switch (self) {
		case FILTER_ITEM_TYPE_PRIORITY:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup ("flag-outline-thick-symbolic");
			result = _tmp0_;
			return result;
		}
		case FILTER_ITEM_TYPE_LABEL:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup ("tag-outline-symbolic");
			result = _tmp1_;
			return result;
		}
		case FILTER_ITEM_TYPE_DUE_DATE:
		{
			gchar* _tmp2_;
			_tmp2_ = g_strdup ("month-symbolic");
			result = _tmp2_;
			return result;
		}
		case FILTER_ITEM_TYPE_SECTION:
		{
			gchar* _tmp3_;
			_tmp3_ = g_strdup ("arrow3-right-symbolic");
			result = _tmp3_;
			return result;
		}
		case FILTER_ITEM_TYPE_ASSIGNMENT:
		{
			gchar* _tmp4_;
			_tmp4_ = g_strdup ("avatar-default-symbolic");
			result = _tmp4_;
			return result;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
}

static GType
filter_item_type_get_type_once (void)
{
	static const GEnumValue values[] = {{FILTER_ITEM_TYPE_PRIORITY, "FILTER_ITEM_TYPE_PRIORITY", "priority"}, {FILTER_ITEM_TYPE_LABEL, "FILTER_ITEM_TYPE_LABEL", "label"}, {FILTER_ITEM_TYPE_DUE_DATE, "FILTER_ITEM_TYPE_DUE_DATE", "due-date"}, {FILTER_ITEM_TYPE_SECTION, "FILTER_ITEM_TYPE_SECTION", "section"}, {FILTER_ITEM_TYPE_ASSIGNMENT, "FILTER_ITEM_TYPE_ASSIGNMENT", "assignment"}, {0, NULL, NULL}};
	GType filter_item_type_type_id;
	filter_item_type_type_id = g_enum_register_static ("FilterItemType", values);
	return filter_item_type_type_id;
}

GType
filter_item_type_get_type (void)
{
	static volatile gsize filter_item_type_type_id__once = 0;
	if (g_once_init_enter (&filter_item_type_type_id__once)) {
		GType filter_item_type_type_id;
		filter_item_type_type_id = filter_item_type_get_type_once ();
		g_once_init_leave (&filter_item_type_type_id__once, filter_item_type_type_id);
	}
	return filter_item_type_type_id__once;
}

gchar*
reminder_type_to_string (ReminderType self)
{
	gchar* result;
	switch (self) {
		case REMINDER_TYPE_ABSOLUTE:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup ("absolute");
			result = _tmp0_;
			return result;
		}
		case REMINDER_TYPE_RELATIVE:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup ("relative");
			result = _tmp1_;
			return result;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
}

static GType
reminder_type_get_type_once (void)
{
	static const GEnumValue values[] = {{REMINDER_TYPE_ABSOLUTE, "REMINDER_TYPE_ABSOLUTE", "absolute"}, {REMINDER_TYPE_RELATIVE, "REMINDER_TYPE_RELATIVE", "relative"}, {0, NULL, NULL}};
	GType reminder_type_type_id;
	reminder_type_type_id = g_enum_register_static ("ReminderType", values);
	return reminder_type_type_id;
}

GType
reminder_type_get_type (void)
{
	static volatile gsize reminder_type_type_id__once = 0;
	if (g_once_init_enter (&reminder_type_type_id__once)) {
		GType reminder_type_type_id;
		reminder_type_type_id = reminder_type_get_type_once ();
		g_once_init_leave (&reminder_type_type_id__once, reminder_type_type_id);
	}
	return reminder_type_type_id__once;
}

gchar*
item_type_to_string (ItemType self)
{
	gchar* result;
	switch (self) {
		case ITEM_TYPE_TASK:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup ("task");
			result = _tmp0_;
			return result;
		}
		case ITEM_TYPE_NOTE:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup ("note");
			result = _tmp1_;
			return result;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
}

ItemType
item_type_parse (const gchar* value)
{
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	static GQuark _tmp1_label1 = 0;
	ItemType result;
	g_return_val_if_fail (value != NULL, 0);
	_tmp0_ = value;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("task")))) {
		switch (0) {
			default:
			{
				result = ITEM_TYPE_TASK;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label1) ? _tmp1_label1 : (_tmp1_label1 = g_quark_from_static_string ("note")))) {
		switch (0) {
			default:
			{
				result = ITEM_TYPE_NOTE;
				return result;
			}
		}
	} else {
		switch (0) {
			default:
			{
				g_assert_not_reached ();
			}
		}
	}
}

static GType
item_type_get_type_once (void)
{
	static const GEnumValue values[] = {{ITEM_TYPE_TASK, "ITEM_TYPE_TASK", "task"}, {ITEM_TYPE_NOTE, "ITEM_TYPE_NOTE", "note"}, {0, NULL, NULL}};
	GType item_type_type_id;
	item_type_type_id = g_enum_register_static ("ItemType", values);
	return item_type_type_id;
}

GType
item_type_get_type (void)
{
	static volatile gsize item_type_type_id__once = 0;
	if (g_once_init_enter (&item_type_type_id__once)) {
		GType item_type_type_id;
		item_type_type_id = item_type_get_type_once ();
		g_once_init_leave (&item_type_type_id__once, item_type_type_id);
	}
	return item_type_type_id__once;
}

ObjectEventType
object_event_type_parse (const gchar* value)
{
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	static GQuark _tmp1_label1 = 0;
	ObjectEventType result;
	g_return_val_if_fail (value != NULL, 0);
	_tmp0_ = value;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("insert")))) {
		switch (0) {
			default:
			{
				result = OBJECT_EVENT_TYPE_INSERT;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label1) ? _tmp1_label1 : (_tmp1_label1 = g_quark_from_static_string ("update")))) {
		switch (0) {
			default:
			{
				result = OBJECT_EVENT_TYPE_UPDATE;
				return result;
			}
		}
	} else {
		switch (0) {
			default:
			{
				g_assert_not_reached ();
			}
		}
	}
}

gchar*
object_event_type_to_string (ObjectEventType self)
{
	gchar* result;
	switch (self) {
		case OBJECT_EVENT_TYPE_INSERT:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup ("insert");
			result = _tmp0_;
			return result;
		}
		case OBJECT_EVENT_TYPE_UPDATE:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup ("update");
			result = _tmp1_;
			return result;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
}

gchar*
object_event_type_get_label (ObjectEventType self)
{
	gchar* result;
	switch (self) {
		case OBJECT_EVENT_TYPE_INSERT:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup (_ ("Task Created"));
			result = _tmp0_;
			return result;
		}
		case OBJECT_EVENT_TYPE_UPDATE:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup (_ ("Task Updated"));
			result = _tmp1_;
			return result;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
}

static GType
object_event_type_get_type_once (void)
{
	static const GEnumValue values[] = {{OBJECT_EVENT_TYPE_INSERT, "OBJECT_EVENT_TYPE_INSERT", "insert"}, {OBJECT_EVENT_TYPE_UPDATE, "OBJECT_EVENT_TYPE_UPDATE", "update"}, {0, NULL, NULL}};
	GType object_event_type_type_id;
	object_event_type_type_id = g_enum_register_static ("ObjectEventType", values);
	return object_event_type_type_id;
}

GType
object_event_type_get_type (void)
{
	static volatile gsize object_event_type_type_id__once = 0;
	if (g_once_init_enter (&object_event_type_type_id__once)) {
		GType object_event_type_type_id;
		object_event_type_type_id = object_event_type_get_type_once ();
		g_once_init_leave (&object_event_type_type_id__once, object_event_type_type_id);
	}
	return object_event_type_type_id__once;
}

ObjectEventKeyType
object_event_key_type_parse (const gchar* value)
{
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	static GQuark _tmp1_label1 = 0;
	static GQuark _tmp1_label2 = 0;
	static GQuark _tmp1_label3 = 0;
	static GQuark _tmp1_label4 = 0;
	static GQuark _tmp1_label5 = 0;
	static GQuark _tmp1_label6 = 0;
	static GQuark _tmp1_label7 = 0;
	static GQuark _tmp1_label8 = 0;
	static GQuark _tmp1_label9 = 0;
	static GQuark _tmp1_label10 = 0;
	ObjectEventKeyType result;
	g_return_val_if_fail (value != NULL, 0);
	_tmp0_ = value;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("content")))) {
		switch (0) {
			default:
			{
				result = OBJECT_EVENT_KEY_TYPE_CONTENT;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label1) ? _tmp1_label1 : (_tmp1_label1 = g_quark_from_static_string ("description")))) {
		switch (0) {
			default:
			{
				result = OBJECT_EVENT_KEY_TYPE_DESCRIPTION;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label2) ? _tmp1_label2 : (_tmp1_label2 = g_quark_from_static_string ("due")))) {
		switch (0) {
			default:
			{
				result = OBJECT_EVENT_KEY_TYPE_DUE;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label3) ? _tmp1_label3 : (_tmp1_label3 = g_quark_from_static_string ("priority")))) {
		switch (0) {
			default:
			{
				result = OBJECT_EVENT_KEY_TYPE_PRIORITY;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label4) ? _tmp1_label4 : (_tmp1_label4 = g_quark_from_static_string ("labels")))) {
		switch (0) {
			default:
			{
				result = OBJECT_EVENT_KEY_TYPE_LABELS;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label5) ? _tmp1_label5 : (_tmp1_label5 = g_quark_from_static_string ("pinned")))) {
		switch (0) {
			default:
			{
				result = OBJECT_EVENT_KEY_TYPE_PINNED;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label6) ? _tmp1_label6 : (_tmp1_label6 = g_quark_from_static_string ("checked")))) {
		switch (0) {
			default:
			{
				result = OBJECT_EVENT_KEY_TYPE_CHECKED;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label7) ? _tmp1_label7 : (_tmp1_label7 = g_quark_from_static_string ("project")))) {
		switch (0) {
			default:
			{
				result = OBJECT_EVENT_KEY_TYPE_PROJECT;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label8) ? _tmp1_label8 : (_tmp1_label8 = g_quark_from_static_string ("section")))) {
		switch (0) {
			default:
			{
				result = OBJECT_EVENT_KEY_TYPE_SECTION;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label9) ? _tmp1_label9 : (_tmp1_label9 = g_quark_from_static_string ("deadline")))) {
		switch (0) {
			default:
			{
				result = OBJECT_EVENT_KEY_TYPE_DEADLINE;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label10) ? _tmp1_label10 : (_tmp1_label10 = g_quark_from_static_string ("parent")))) {
		switch (0) {
			default:
			{
				result = OBJECT_EVENT_KEY_TYPE_PARENT;
				return result;
			}
		}
	} else {
		switch (0) {
			default:
			{
				g_assert_not_reached ();
			}
		}
	}
}

gchar*
object_event_key_type_get_label (ObjectEventKeyType self)
{
	gchar* result;
	switch (self) {
		case OBJECT_EVENT_KEY_TYPE_CONTENT:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup (_ ("Content"));
			result = _tmp0_;
			return result;
		}
		case OBJECT_EVENT_KEY_TYPE_DESCRIPTION:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup (_ ("Description"));
			result = _tmp1_;
			return result;
		}
		case OBJECT_EVENT_KEY_TYPE_DUE:
		{
			gchar* _tmp2_;
			_tmp2_ = g_strdup (_ ("Scheduled"));
			result = _tmp2_;
			return result;
		}
		case OBJECT_EVENT_KEY_TYPE_PRIORITY:
		{
			gchar* _tmp3_;
			_tmp3_ = g_strdup (_ ("Priority"));
			result = _tmp3_;
			return result;
		}
		case OBJECT_EVENT_KEY_TYPE_LABELS:
		{
			gchar* _tmp4_;
			_tmp4_ = g_strdup (_ ("Labels"));
			result = _tmp4_;
			return result;
		}
		case OBJECT_EVENT_KEY_TYPE_PINNED:
		{
			gchar* _tmp5_;
			_tmp5_ = g_strdup (_ ("Pin"));
			result = _tmp5_;
			return result;
		}
		case OBJECT_EVENT_KEY_TYPE_DEADLINE:
		{
			gchar* _tmp6_;
			_tmp6_ = g_strdup (_ ("Deadline"));
			result = _tmp6_;
			return result;
		}
		case OBJECT_EVENT_KEY_TYPE_PARENT:
		{
			gchar* _tmp7_;
			_tmp7_ = g_strdup (_ ("Parent task"));
			result = _tmp7_;
			return result;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
}

static GType
object_event_key_type_get_type_once (void)
{
	static const GEnumValue values[] = {{OBJECT_EVENT_KEY_TYPE_CONTENT, "OBJECT_EVENT_KEY_TYPE_CONTENT", "content"}, {OBJECT_EVENT_KEY_TYPE_DESCRIPTION, "OBJECT_EVENT_KEY_TYPE_DESCRIPTION", "description"}, {OBJECT_EVENT_KEY_TYPE_DUE, "OBJECT_EVENT_KEY_TYPE_DUE", "due"}, {OBJECT_EVENT_KEY_TYPE_PRIORITY, "OBJECT_EVENT_KEY_TYPE_PRIORITY", "priority"}, {OBJECT_EVENT_KEY_TYPE_LABELS, "OBJECT_EVENT_KEY_TYPE_LABELS", "labels"}, {OBJECT_EVENT_KEY_TYPE_PINNED, "OBJECT_EVENT_KEY_TYPE_PINNED", "pinned"}, {OBJECT_EVENT_KEY_TYPE_CHECKED, "OBJECT_EVENT_KEY_TYPE_CHECKED", "checked"}, {OBJECT_EVENT_KEY_TYPE_PROJECT, "OBJECT_EVENT_KEY_TYPE_PROJECT", "project"}, {OBJECT_EVENT_KEY_TYPE_SECTION, "OBJECT_EVENT_KEY_TYPE_SECTION", "section"}, {OBJECT_EVENT_KEY_TYPE_DEADLINE, "OBJECT_EVENT_KEY_TYPE_DEADLINE", "deadline"}, {OBJECT_EVENT_KEY_TYPE_PARENT, "OBJECT_EVENT_KEY_TYPE_PARENT", "parent"}, {0, NULL, NULL}};
	GType object_event_key_type_type_id;
	object_event_key_type_type_id = g_enum_register_static ("ObjectEventKeyType", values);
	return object_event_key_type_type_id;
}

GType
object_event_key_type_get_type (void)
{
	static volatile gsize object_event_key_type_type_id__once = 0;
	if (g_once_init_enter (&object_event_key_type_type_id__once)) {
		GType object_event_key_type_type_id;
		object_event_key_type_type_id = object_event_key_type_get_type_once ();
		g_once_init_leave (&object_event_key_type_type_id__once, object_event_key_type_type_id);
	}
	return object_event_key_type_type_id__once;
}

static GType
label_picker_type_get_type_once (void)
{
	static const GEnumValue values[] = {{LABEL_PICKER_TYPE_FILTER_AND_CREATE, "LABEL_PICKER_TYPE_FILTER_AND_CREATE", "filter-and-create"}, {LABEL_PICKER_TYPE_FILTER_ONLY, "LABEL_PICKER_TYPE_FILTER_ONLY", "filter-only"}, {0, NULL, NULL}};
	GType label_picker_type_type_id;
	label_picker_type_type_id = g_enum_register_static ("LabelPickerType", values);
	return label_picker_type_type_id;
}

GType
label_picker_type_get_type (void)
{
	static volatile gsize label_picker_type_type_id__once = 0;
	if (g_once_init_enter (&label_picker_type_type_id__once)) {
		GType label_picker_type_type_id;
		label_picker_type_type_id = label_picker_type_get_type_once ();
		g_once_init_leave (&label_picker_type_type_id__once, label_picker_type_type_id);
	}
	return label_picker_type_type_id__once;
}

ItemPriority
item_priority_parse (const gchar* value)
{
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	static GQuark _tmp1_label1 = 0;
	static GQuark _tmp1_label2 = 0;
	static GQuark _tmp1_label3 = 0;
	ItemPriority result;
	g_return_val_if_fail (value != NULL, 0);
	_tmp0_ = value;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("p1")))) {
		switch (0) {
			default:
			{
				result = ITEM_PRIORITY_HIGHT;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label1) ? _tmp1_label1 : (_tmp1_label1 = g_quark_from_static_string ("p2")))) {
		switch (0) {
			default:
			{
				result = ITEM_PRIORITY_MEDIUM;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label2) ? _tmp1_label2 : (_tmp1_label2 = g_quark_from_static_string ("p3")))) {
		switch (0) {
			default:
			{
				result = ITEM_PRIORITY_LOW;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label3) ? _tmp1_label3 : (_tmp1_label3 = g_quark_from_static_string ("p4")))) {
		switch (0) {
			default:
			{
				result = ITEM_PRIORITY_NONE;
				return result;
			}
		}
	} else {
		switch (0) {
			default:
			{
				result = ITEM_PRIORITY_NONE;
				return result;
			}
		}
	}
}

gchar*
item_priority_get_color (ItemPriority self)
{
	gchar* result;
	switch (self) {
		case ITEM_PRIORITY_HIGHT:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup ("#ff7066");
			result = _tmp0_;
			return result;
		}
		case ITEM_PRIORITY_MEDIUM:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup ("#ff9914");
			result = _tmp1_;
			return result;
		}
		case ITEM_PRIORITY_LOW:
		{
			gchar* _tmp2_;
			_tmp2_ = g_strdup ("#5297ff");
			result = _tmp2_;
			return result;
		}
		case ITEM_PRIORITY_NONE:
		{
			const gchar* _tmp3_ = NULL;
			ServicesSettings* _tmp4_;
			ServicesSettings* _tmp5_;
			GSettings* _tmp6_;
			gboolean _tmp7_;
			gchar* _tmp8_;
			_tmp4_ = services_settings_get_default ();
			_tmp5_ = _tmp4_;
			_tmp6_ = _tmp5_->settings;
			_tmp7_ = g_settings_get_boolean (_tmp6_, "dark-mode");
			_g_object_unref0 (_tmp5_);
			if (_tmp7_) {
				_tmp3_ = "#fafafa";
			} else {
				_tmp3_ = "#333333";
			}
			_tmp8_ = g_strdup (_tmp3_);
			result = _tmp8_;
			return result;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
}

static GType
item_priority_get_type_once (void)
{
	static const GEnumValue values[] = {{ITEM_PRIORITY_HIGHT, "ITEM_PRIORITY_HIGHT", "hight"}, {ITEM_PRIORITY_MEDIUM, "ITEM_PRIORITY_MEDIUM", "medium"}, {ITEM_PRIORITY_LOW, "ITEM_PRIORITY_LOW", "low"}, {ITEM_PRIORITY_NONE, "ITEM_PRIORITY_NONE", "none"}, {0, NULL, NULL}};
	GType item_priority_type_id;
	item_priority_type_id = g_enum_register_static ("ItemPriority", values);
	return item_priority_type_id;
}

GType
item_priority_get_type (void)
{
	static volatile gsize item_priority_type_id__once = 0;
	if (g_once_init_enter (&item_priority_type_id__once)) {
		GType item_priority_type_id;
		item_priority_type_id = item_priority_get_type_once ();
		g_once_init_leave (&item_priority_type_id__once, item_priority_type_id);
	}
	return item_priority_type_id__once;
}

gchar*
sort_order_type_to_string (SortOrderType self)
{
	gchar* result;
	switch (self) {
		case SORT_ORDER_TYPE_ASC:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup ("asc");
			result = _tmp0_;
			return result;
		}
		case SORT_ORDER_TYPE_DESC:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup ("desc");
			result = _tmp1_;
			return result;
		}
		default:
		{
			gchar* _tmp2_;
			_tmp2_ = g_strdup ("asc");
			result = _tmp2_;
			return result;
		}
	}
}

SortOrderType
sort_order_type_parse (const gchar* value)
{
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	static GQuark _tmp1_label1 = 0;
	SortOrderType result;
	g_return_val_if_fail (value != NULL, 0);
	_tmp0_ = value;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("asc")))) {
		switch (0) {
			default:
			{
				result = SORT_ORDER_TYPE_ASC;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label1) ? _tmp1_label1 : (_tmp1_label1 = g_quark_from_static_string ("desc")))) {
		switch (0) {
			default:
			{
				result = SORT_ORDER_TYPE_DESC;
				return result;
			}
		}
	} else {
		switch (0) {
			default:
			{
				result = SORT_ORDER_TYPE_ASC;
				return result;
			}
		}
	}
}

static GType
sort_order_type_get_type_once (void)
{
	static const GEnumValue values[] = {{SORT_ORDER_TYPE_ASC, "SORT_ORDER_TYPE_ASC", "asc"}, {SORT_ORDER_TYPE_DESC, "SORT_ORDER_TYPE_DESC", "desc"}, {0, NULL, NULL}};
	GType sort_order_type_type_id;
	sort_order_type_type_id = g_enum_register_static ("SortOrderType", values);
	return sort_order_type_type_id;
}

GType
sort_order_type_get_type (void)
{
	static volatile gsize sort_order_type_type_id__once = 0;
	if (g_once_init_enter (&sort_order_type_type_id__once)) {
		GType sort_order_type_type_id;
		sort_order_type_type_id = sort_order_type_get_type_once ();
		g_once_init_leave (&sort_order_type_type_id__once, sort_order_type_type_id);
	}
	return sort_order_type_type_id__once;
}

gchar*
sorted_by_type_to_string (SortedByType self)
{
	gchar* result;
	switch (self) {
		case SORTED_BY_TYPE_MANUAL:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup ("manual");
			result = _tmp0_;
			return result;
		}
		case SORTED_BY_TYPE_NAME:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup ("name");
			result = _tmp1_;
			return result;
		}
		case SORTED_BY_TYPE_DUE_DATE:
		{
			gchar* _tmp2_;
			_tmp2_ = g_strdup ("due-date");
			result = _tmp2_;
			return result;
		}
		case SORTED_BY_TYPE_ADDED_DATE:
		{
			gchar* _tmp3_;
			_tmp3_ = g_strdup ("added-date");
			result = _tmp3_;
			return result;
		}
		case SORTED_BY_TYPE_UPDATED_DATE:
		{
			gchar* _tmp4_;
			_tmp4_ = g_strdup ("updated-date");
			result = _tmp4_;
			return result;
		}
		case SORTED_BY_TYPE_PRIORITY:
		{
			gchar* _tmp5_;
			_tmp5_ = g_strdup ("priority");
			result = _tmp5_;
			return result;
		}
		default:
		{
			gchar* _tmp6_;
			_tmp6_ = g_strdup ("manual");
			result = _tmp6_;
			return result;
		}
	}
}

SortedByType
sorted_by_type_parse (const gchar* value)
{
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	static GQuark _tmp1_label1 = 0;
	static GQuark _tmp1_label2 = 0;
	static GQuark _tmp1_label3 = 0;
	static GQuark _tmp1_label4 = 0;
	static GQuark _tmp1_label5 = 0;
	SortedByType result;
	g_return_val_if_fail (value != NULL, 0);
	_tmp0_ = value;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("manual")))) {
		switch (0) {
			default:
			{
				result = SORTED_BY_TYPE_MANUAL;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label1) ? _tmp1_label1 : (_tmp1_label1 = g_quark_from_static_string ("name")))) {
		switch (0) {
			default:
			{
				result = SORTED_BY_TYPE_NAME;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label2) ? _tmp1_label2 : (_tmp1_label2 = g_quark_from_static_string ("due-date")))) {
		switch (0) {
			default:
			{
				result = SORTED_BY_TYPE_DUE_DATE;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label3) ? _tmp1_label3 : (_tmp1_label3 = g_quark_from_static_string ("added-date")))) {
		switch (0) {
			default:
			{
				result = SORTED_BY_TYPE_ADDED_DATE;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label4) ? _tmp1_label4 : (_tmp1_label4 = g_quark_from_static_string ("updated-date")))) {
		switch (0) {
			default:
			{
				result = SORTED_BY_TYPE_UPDATED_DATE;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label5) ? _tmp1_label5 : (_tmp1_label5 = g_quark_from_static_string ("priority")))) {
		switch (0) {
			default:
			{
				result = SORTED_BY_TYPE_PRIORITY;
				return result;
			}
		}
	} else {
		switch (0) {
			default:
			{
				result = SORTED_BY_TYPE_MANUAL;
				return result;
			}
		}
	}
}

static GType
sorted_by_type_get_type_once (void)
{
	static const GEnumValue values[] = {{SORTED_BY_TYPE_MANUAL, "SORTED_BY_TYPE_MANUAL", "manual"}, {SORTED_BY_TYPE_NAME, "SORTED_BY_TYPE_NAME", "name"}, {SORTED_BY_TYPE_DUE_DATE, "SORTED_BY_TYPE_DUE_DATE", "due-date"}, {SORTED_BY_TYPE_ADDED_DATE, "SORTED_BY_TYPE_ADDED_DATE", "added-date"}, {SORTED_BY_TYPE_UPDATED_DATE, "SORTED_BY_TYPE_UPDATED_DATE", "updated-date"}, {SORTED_BY_TYPE_PRIORITY, "SORTED_BY_TYPE_PRIORITY", "priority"}, {0, NULL, NULL}};
	GType sorted_by_type_type_id;
	sorted_by_type_type_id = g_enum_register_static ("SortedByType", values);
	return sorted_by_type_type_id;
}

GType
sorted_by_type_get_type (void)
{
	static volatile gsize sorted_by_type_type_id__once = 0;
	if (g_once_init_enter (&sorted_by_type_type_id__once)) {
		GType sorted_by_type_type_id;
		sorted_by_type_type_id = sorted_by_type_get_type_once ();
		g_once_init_leave (&sorted_by_type_type_id__once, sorted_by_type_type_id);
	}
	return sorted_by_type_type_id__once;
}

gchar*
appearance_to_string (Appearance self)
{
	gchar* result;
	switch (self) {
		case APPEARANCE_LIGHT:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup ("light");
			result = _tmp0_;
			return result;
		}
		case APPEARANCE_DARK:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup ("dark");
			result = _tmp1_;
			return result;
		}
		case APPEARANCE_DARK_BLUE:
		{
			gchar* _tmp2_;
			_tmp2_ = g_strdup ("dark-blue");
			result = _tmp2_;
			return result;
		}
		default:
		{
			gchar* _tmp3_;
			_tmp3_ = g_strdup ("light");
			result = _tmp3_;
			return result;
		}
	}
}

Appearance
appearance_parse (gint value)
{
	Appearance result;
	switch (value) {
		case 0:
		{
			result = APPEARANCE_LIGHT;
			return result;
		}
		case 1:
		{
			result = APPEARANCE_DARK;
			return result;
		}
		case 2:
		{
			result = APPEARANCE_DARK_BLUE;
			return result;
		}
		default:
		{
			result = APPEARANCE_LIGHT;
			return result;
		}
	}
}

Appearance
appearance_get_default (void)
{
	ServicesSettings* _tmp0_;
	ServicesSettings* _tmp1_;
	GSettings* _tmp2_;
	gint _tmp3_;
	Appearance result;
	_tmp0_ = services_settings_get_default ();
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_->settings;
	_tmp3_ = g_settings_get_enum (_tmp2_, "appearance");
	_g_object_unref0 (_tmp1_);
	switch (_tmp3_) {
		case 0:
		{
			result = APPEARANCE_LIGHT;
			return result;
		}
		case 1:
		{
			result = APPEARANCE_DARK;
			return result;
		}
		case 2:
		{
			result = APPEARANCE_DARK_BLUE;
			return result;
		}
		default:
		{
			result = APPEARANCE_LIGHT;
			return result;
		}
	}
}

static GType
appearance_get_type_once (void)
{
	static const GEnumValue values[] = {{APPEARANCE_LIGHT, "APPEARANCE_LIGHT", "light"}, {APPEARANCE_DARK, "APPEARANCE_DARK", "dark"}, {APPEARANCE_DARK_BLUE, "APPEARANCE_DARK_BLUE", "dark-blue"}, {0, NULL, NULL}};
	GType appearance_type_id;
	appearance_type_id = g_enum_register_static ("Appearance", values);
	return appearance_type_id;
}

GType
appearance_get_type (void)
{
	static volatile gsize appearance_type_id__once = 0;
	if (g_once_init_enter (&appearance_type_id__once)) {
		GType appearance_type_id;
		appearance_type_id = appearance_get_type_once ();
		g_once_init_leave (&appearance_type_id__once, appearance_type_id);
	}
	return appearance_type_id__once;
}

static GType
sync_error_type_get_type_once (void)
{
	static const GEnumValue values[] = {{SYNC_ERROR_TYPE_AUTH_EXPIRED, "SYNC_ERROR_TYPE_AUTH_EXPIRED", "auth-expired"}, {SYNC_ERROR_TYPE_SERVER_ERROR, "SYNC_ERROR_TYPE_SERVER_ERROR", "server-error"}, {SYNC_ERROR_TYPE_NETWORK_ERROR, "SYNC_ERROR_TYPE_NETWORK_ERROR", "network-error"}, {0, NULL, NULL}};
	GType sync_error_type_type_id;
	sync_error_type_type_id = g_enum_register_static ("SyncErrorType", values);
	return sync_error_type_type_id;
}

GType
sync_error_type_get_type (void)
{
	static volatile gsize sync_error_type_type_id__once = 0;
	if (g_once_init_enter (&sync_error_type_type_id__once)) {
		GType sync_error_type_type_id;
		sync_error_type_type_id = sync_error_type_get_type_once ();
		g_once_init_leave (&sync_error_type_type_id__once, sync_error_type_type_id);
	}
	return sync_error_type_type_id__once;
}

static inline gpointer
sync_status_get_instance_private (SyncStatus* self)
{
	return G_STRUCT_MEMBER_P (self, SyncStatus_private_offset);
}

SyncStatus*
sync_status_construct (GType object_type,
                       SyncErrorType error_type,
                       const gchar* title,
                       const gchar* description)
{
	SyncStatus * self = NULL;
	g_return_val_if_fail (title != NULL, NULL);
	g_return_val_if_fail (description != NULL, NULL);
	self = (SyncStatus*) g_object_new (object_type, "error-type", error_type, "title", title, "description", description, NULL);
	return self;
}

SyncStatus*
sync_status_new (SyncErrorType error_type,
                 const gchar* title,
                 const gchar* description)
{
	return sync_status_construct (TYPE_SYNC_STATUS, error_type, title, description);
}

SyncErrorType
sync_status_get_error_type (SyncStatus* self)
{
	SyncErrorType result;
	g_return_val_if_fail (self != NULL, 0);
	result = self->priv->_error_type;
	return result;
}

void
sync_status_set_error_type (SyncStatus* self,
                            SyncErrorType value)
{
	SyncErrorType old_value;
	g_return_if_fail (self != NULL);
	old_value = sync_status_get_error_type (self);
	if (old_value != value) {
		self->priv->_error_type = value;
		g_object_notify_by_pspec ((GObject *) self, sync_status_properties[SYNC_STATUS_ERROR_TYPE_PROPERTY]);
	}
}

const gchar*
sync_status_get_title (SyncStatus* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_title;
	result = _tmp0_;
	return result;
}

void
sync_status_set_title (SyncStatus* self,
                       const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = sync_status_get_title (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_title);
		self->priv->_title = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, sync_status_properties[SYNC_STATUS_TITLE_PROPERTY]);
	}
}

const gchar*
sync_status_get_description (SyncStatus* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_description;
	result = _tmp0_;
	return result;
}

void
sync_status_set_description (SyncStatus* self,
                             const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = sync_status_get_description (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_description);
		self->priv->_description = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, sync_status_properties[SYNC_STATUS_DESCRIPTION_PROPERTY]);
	}
}

gchar*
sync_status_get_tooltip (SyncStatus* self)
{
	gchar* result;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_title;
	_tmp1_ = self->priv->_description;
	_tmp2_ = g_strdup_printf ("%s — %s", _tmp0_, _tmp1_);
	result = _tmp2_;
	return result;
}

static void
sync_status_class_init (SyncStatusClass * klass,
                        gpointer klass_data)
{
	sync_status_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &SyncStatus_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_sync_status_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_sync_status_set_property;
	G_OBJECT_CLASS (klass)->finalize = sync_status_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), SYNC_STATUS_ERROR_TYPE_PROPERTY, sync_status_properties[SYNC_STATUS_ERROR_TYPE_PROPERTY] = g_param_spec_enum ("error-type", "error-type", "error-type", TYPE_SYNC_ERROR_TYPE, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), SYNC_STATUS_TITLE_PROPERTY, sync_status_properties[SYNC_STATUS_TITLE_PROPERTY] = g_param_spec_string ("title", "title", "title", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), SYNC_STATUS_DESCRIPTION_PROPERTY, sync_status_properties[SYNC_STATUS_DESCRIPTION_PROPERTY] = g_param_spec_string ("description", "description", "description", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), SYNC_STATUS_TOOLTIP_PROPERTY, sync_status_properties[SYNC_STATUS_TOOLTIP_PROPERTY] = g_param_spec_string ("tooltip", "tooltip", "tooltip", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
}

static void
sync_status_instance_init (SyncStatus * self,
                           gpointer klass)
{
	self->priv = sync_status_get_instance_private (self);
}

static void
sync_status_finalize (GObject * obj)
{
	SyncStatus * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SYNC_STATUS, SyncStatus);
	_g_free0 (self->priv->_title);
	_g_free0 (self->priv->_description);
	G_OBJECT_CLASS (sync_status_parent_class)->finalize (obj);
}

static GType
sync_status_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (SyncStatusClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) sync_status_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SyncStatus), 0, (GInstanceInitFunc) sync_status_instance_init, NULL };
	GType sync_status_type_id;
	sync_status_type_id = g_type_register_static (G_TYPE_OBJECT, "SyncStatus", &g_define_type_info, 0);
	SyncStatus_private_offset = g_type_add_instance_private (sync_status_type_id, sizeof (SyncStatusPrivate));
	return sync_status_type_id;
}

GType
sync_status_get_type (void)
{
	static volatile gsize sync_status_type_id__once = 0;
	if (g_once_init_enter (&sync_status_type_id__once)) {
		GType sync_status_type_id;
		sync_status_type_id = sync_status_get_type_once ();
		g_once_init_leave (&sync_status_type_id__once, sync_status_type_id);
	}
	return sync_status_type_id__once;
}

static void
_vala_sync_status_get_property (GObject * object,
                                guint property_id,
                                GValue * value,
                                GParamSpec * pspec)
{
	SyncStatus * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_SYNC_STATUS, SyncStatus);
	switch (property_id) {
		case SYNC_STATUS_ERROR_TYPE_PROPERTY:
		g_value_set_enum (value, sync_status_get_error_type (self));
		break;
		case SYNC_STATUS_TITLE_PROPERTY:
		g_value_set_string (value, sync_status_get_title (self));
		break;
		case SYNC_STATUS_DESCRIPTION_PROPERTY:
		g_value_set_string (value, sync_status_get_description (self));
		break;
		case SYNC_STATUS_TOOLTIP_PROPERTY:
		g_value_take_string (value, sync_status_get_tooltip (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_sync_status_set_property (GObject * object,
                                guint property_id,
                                const GValue * value,
                                GParamSpec * pspec)
{
	SyncStatus * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_SYNC_STATUS, SyncStatus);
	switch (property_id) {
		case SYNC_STATUS_ERROR_TYPE_PROPERTY:
		sync_status_set_error_type (self, g_value_get_enum (value));
		break;
		case SYNC_STATUS_TITLE_PROPERTY:
		sync_status_set_title (self, g_value_get_string (value));
		break;
		case SYNC_STATUS_DESCRIPTION_PROPERTY:
		sync_status_set_description (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

gchar*
markdown_setting_to_string (MarkdownSetting self)
{
	gchar* result;
	switch (self) {
		case MARKDOWN_SETTING_ENABLED:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup ("enabled");
			result = _tmp0_;
			return result;
		}
		case MARKDOWN_SETTING_DISABLED:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup ("disabled");
			result = _tmp1_;
			return result;
		}
		default:
		{
			gchar* _tmp2_;
			_tmp2_ = g_strdup ("global-default");
			result = _tmp2_;
			return result;
		}
	}
}

MarkdownSetting
markdown_setting_parse (const gchar* value)
{
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	static GQuark _tmp1_label1 = 0;
	MarkdownSetting result;
	g_return_val_if_fail (value != NULL, 0);
	_tmp0_ = value;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("enabled")))) {
		switch (0) {
			default:
			{
				result = MARKDOWN_SETTING_ENABLED;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label1) ? _tmp1_label1 : (_tmp1_label1 = g_quark_from_static_string ("disabled")))) {
		switch (0) {
			default:
			{
				result = MARKDOWN_SETTING_DISABLED;
				return result;
			}
		}
	} else {
		switch (0) {
			default:
			{
				result = MARKDOWN_SETTING_GLOBAL_DEFAULT;
				return result;
			}
		}
	}
}

static GType
markdown_setting_get_type_once (void)
{
	static const GEnumValue values[] = {{MARKDOWN_SETTING_GLOBAL_DEFAULT, "MARKDOWN_SETTING_GLOBAL_DEFAULT", "global-default"}, {MARKDOWN_SETTING_ENABLED, "MARKDOWN_SETTING_ENABLED", "enabled"}, {MARKDOWN_SETTING_DISABLED, "MARKDOWN_SETTING_DISABLED", "disabled"}, {0, NULL, NULL}};
	GType markdown_setting_type_id;
	markdown_setting_type_id = g_enum_register_static ("MarkdownSetting", values);
	return markdown_setting_type_id;
}

GType
markdown_setting_get_type (void)
{
	static volatile gsize markdown_setting_type_id__once = 0;
	if (g_once_init_enter (&markdown_setting_type_id__once)) {
		GType markdown_setting_type_id;
		markdown_setting_type_id = markdown_setting_get_type_once ();
		g_once_init_leave (&markdown_setting_type_id__once, markdown_setting_type_id);
	}
	return markdown_setting_type_id__once;
}

